# Navigation Simulator for Mobile Robot

[![Python](https://img.shields.io/badge/python-3.5%20%7C%203.6%20%7C%203.7-blue)](https://www.python.org)
[![Build Status](https://travis-ci.com/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot.svg?branch=master)](https://travis-ci.com/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot)
[![Coverage Status](https://coveralls.io/repos/github/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot/badge.svg?branch=master)](https://coveralls.io/github/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot?branch=master)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot)

![nsmr](assets/nsmr.gif)

## Installation
NSMR can be installed by using `pip`.

```
$ pip install nsmr
```

If installing from source code, execute the following commands.
```
$ git clone https://github.com/Jumpei-Arima/Navigation_Simulator_for_Mobile_Robot
$ cd Navigation_Simulator_for_Mobile_Robot
$ pip install -e .
```

For examples see example
```
python examples/run_env.py
```
